about summary refs log tree commit diff homepage
path: root/tools
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2009-06-03 02:55:55 +0000
committerDaniel Dunbar <daniel@zuster.org>2009-06-03 02:55:55 +0000
commitbcfc431c7133fb93f93c1768fd900f049e365323 (patch)
tree342f062b62eb009ce806bc2de1678e63516ff915 /tools
parent4aea9d3d47e7e47630704fdf6628221fa45f6151 (diff)
downloadklee-bcfc431c7133fb93f93c1768fd900f049e365323.tar.gz
Update a few things that got forgotten in the great "bout" to "ktest"
renaming of '08.


git-svn-id: https://llvm.org/svn/llvm-project/klee/trunk@72748 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'tools')
-rw-r--r--tools/klee/main.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/tools/klee/main.cpp b/tools/klee/main.cpp
index de18edcc..641577a2 100644
--- a/tools/klee/main.cpp
+++ b/tools/klee/main.cpp
@@ -192,7 +192,7 @@ private:
   unsigned m_testIndex;  // number of tests written so far
   unsigned m_pathsExplored; // number of paths explored so far
 
   // used for writing .bout files
   int m_argc;
   char **m_argv;
 
@@ -364,7 +364,7 @@ std::ostream *KleeHandler::openTestFile(const std::string &suffix, unsigned id)
 }
 
 
 /* Outputs all files (.bout, .pc, .cov etc.) describing a test case */
 void KleeHandler::processTestCase(const ExecutionState &state,
                                   const char *errorMessage, 
                                   const char *errorSuffix) {
@@ -509,13 +509,14 @@ void KleeHandler::getOutFiles(std::string path,
   std::set<llvm::sys::Path> contents;
   std::string error;
   if (p.getDirectoryContents(contents, &error)) {
-    llvm::cerr << "ERROR: unable to read output directory: " << path << ": " << error << "\n";
+    llvm::cerr << "ERROR: unable to read output directory: " << path 
+               << ": " << error << "\n";
     exit(1);
   }
   for (std::set<llvm::sys::Path>::iterator it = contents.begin(),
          ie = contents.end(); it != ie; ++it) {
     std::string f = it->toString();
-    if (f.substr(f.size()-5,f.size()) == ".bout") {
+    if (f.substr(f.size()-6,f.size()) == ".ktest") {
       results.push_back(f);
     }
   }
@@ -1300,7 +1301,7 @@ int main(int argc, char **argv, char **envp) {
       interpreter->setReplayOut(out);
       llvm::cerr << "KLEE: replaying: " << *it << " (" << kTest_numBytes(out) << " bytes)"
                  << " (" << ++i << "/" << outFiles.size() << ")\n";
       // XXX should put envp in .bout ?
       interpreter->runFunctionAsMain(mainFn, out->numArgs, out->args, pEnvp);
       if (interrupted) break;
     }
@@ -192,7 +192,7 @@ private:
   unsigned m_pathsExplored; // number of paths explored so far
 
-  // used for writing .bout files
+  // used for writing .ktest files
   int m_argc;
   char **m_argv;
@@ -364,7 +364,7 @@ std::ostream *KleeHandler::openTestFile(const std::string &suffix, unsigned id)
 
 
-/* Outputs all files (.bout, .pc, .cov etc.) describing a test case */
+/* Outputs all files (.ktest, .pc, .cov etc.) describing a test case */
 void KleeHandler::processTestCase(const ExecutionState &state,
                                   const char *errorMessage, 
@@ -1300,7 +1301,7 @@ int main(int argc, char **argv, char **envp) {
       llvm::cerr << "KLEE: replaying: " << *it << " (" << kTest_numBytes(out) << " bytes)"
                  << " (" << ++i << "/" << outFiles.size() << ")\n";
-      // XXX should put envp in .bout ?
+      // XXX should put envp in .ktest ?
       interpreter->runFunctionAsMain(mainFn, out->numArgs, out->args, pEnvp);
       if (interrupted) break;